@@ -82,3 +82,7 @@ def get_file_md5sum(file):
 def get_str_md5sum(content):
     import hashlib
     return hashlib.md5(content.encode('utf8')).hexdigest()
+
+def append_text_file(file_name, file_content):
+    with open(file_name,"a") as file:
+        file.write(file_content)
